@@ -94,9 +94,6 @@ class Predictor(ApiObject):
         Raises:
             TypeError, ValueError
         """
-        if self.status == 'disabled':
-            raise RuntimeError('predictor is disabled')
-
         return add_model(predictor, output_dir, tag, metric, metric_stats, self.predictor_id)
 
     @classmethod
