@@ -195,7 +195,7 @@ class BinaryTransformer(BaseEstimator, TransformerMixin):
             transforms.append(binary)
         return pd.concat(transforms, axis=1).mask(pd.isnull(X)).astype('O')
 
-class NominalTransformer(BaseEstimator, TransformerMixin):
+class CategoricalTransformer(BaseEstimator, TransformerMixin):
     """Converts categoricals to nominals and replaces missing and unknowns with nan."""
     def fit(self, X, y = None):
         """
